*tp++ = gdk_app_launch_context_get_type();
*tp++ = gdk_axis_use_get_type();
*tp++ = gdk_byte_order_get_type();
*tp++ = gdk_cap_style_get_type();
*tp++ = gdk_color_get_type();
*tp++ = gdk_colormap_get_type();
*tp++ = gdk_colorspace_get_type();
*tp++ = gdk_crossing_mode_get_type();
*tp++ = gdk_cursor_get_type();
*tp++ = gdk_cursor_type_get_type();
*tp++ = gdk_device_get_type();
*tp++ = gdk_display_get_type();
*tp++ = gdk_display_manager_get_type();
*tp++ = gdk_drag_action_get_type();
*tp++ = gdk_drag_context_get_type();
*tp++ = gdk_drag_protocol_get_type();
*tp++ = gdk_drawable_get_type();
*tp++ = gdk_event_get_type();
*tp++ = gdk_event_mask_get_type();
*tp++ = gdk_event_type_get_type();
*tp++ = gdk_extension_mode_get_type();
*tp++ = gdk_fill_get_type();
*tp++ = gdk_fill_rule_get_type();
*tp++ = gdk_filter_return_get_type();
*tp++ = gdk_font_get_type();
*tp++ = gdk_font_type_get_type();
*tp++ = gdk_function_get_type();
*tp++ = gdk_gc_get_type();
*tp++ = gdk_gc_values_mask_get_type();
*tp++ = gdk_grab_status_get_type();
*tp++ = gdk_gravity_get_type();
*tp++ = gdk_image_get_type();
*tp++ = gdk_image_type_get_type();
*tp++ = gdk_input_condition_get_type();
*tp++ = gdk_input_mode_get_type();
*tp++ = gdk_input_source_get_type();
*tp++ = gdk_interp_type_get_type();
*tp++ = gdk_join_style_get_type();
*tp++ = gdk_keymap_get_type();
*tp++ = gdk_line_style_get_type();
*tp++ = gdk_modifier_type_get_type();
*tp++ = gdk_notify_type_get_type();
*tp++ = gdk_overlap_type_get_type();
*tp++ = gdk_owner_change_get_type();
*tp++ = gdk_pango_renderer_get_type();
*tp++ = gdk_pixbuf_alpha_mode_get_type();
*tp++ = gdk_pixbuf_animation_get_type();
*tp++ = gdk_pixbuf_animation_iter_get_type();
*tp++ = gdk_pixbuf_error_get_type();
*tp++ = gdk_pixbuf_format_get_type();
*tp++ = gdk_pixbuf_get_type();
*tp++ = gdk_pixbuf_loader_get_type();
*tp++ = gdk_pixbuf_rotation_get_type();
*tp++ = gdk_pixbuf_simple_anim_get_type();
*tp++ = gdk_pixbuf_simple_anim_iter_get_type();
*tp++ = gdk_pixmap_get_type();
*tp++ = gdk_property_state_get_type();
*tp++ = gdk_prop_mode_get_type();
*tp++ = gdk_rectangle_get_type();
*tp++ = gdk_rgb_dither_get_type();
*tp++ = gdk_screen_get_type();
*tp++ = gdk_scroll_direction_get_type();
*tp++ = gdk_setting_action_get_type();
*tp++ = gdk_status_get_type();
*tp++ = gdk_subwindow_mode_get_type();
*tp++ = gdk_visibility_state_get_type();
*tp++ = gdk_visual_get_type();
*tp++ = gdk_visual_type_get_type();
*tp++ = gdk_window_attributes_type_get_type();
*tp++ = gdk_window_class_get_type();
*tp++ = gdk_window_edge_get_type();
*tp++ = gdk_window_hints_get_type();
*tp++ = gdk_window_object_get_type();
*tp++ = gdk_window_state_get_type();
*tp++ = gdk_window_type_get_type();
*tp++ = gdk_window_type_hint_get_type();
*tp++ = gdk_wm_decoration_get_type();
*tp++ = gdk_wm_function_get_type();
*tp++ = gtk_about_dialog_get_type();
*tp++ = gtk_accel_flags_get_type();
*tp++ = gtk_accel_group_get_type();
*tp++ = gtk_accel_label_get_type();
*tp++ = gtk_accel_map_get_type();
*tp++ = gtk_accessible_get_type();
*tp++ = gtk_action_get_type();
*tp++ = gtk_action_group_get_type();
*tp++ = gtk_activatable_get_type();
*tp++ = gtk_adjustment_get_type();
*tp++ = gtk_alignment_get_type();
*tp++ = gtk_anchor_type_get_type();
*tp++ = gtk_arg_flags_get_type();
*tp++ = gtk_arrow_get_type();
*tp++ = gtk_arrow_placement_get_type();
*tp++ = gtk_arrow_type_get_type();
*tp++ = gtk_aspect_frame_get_type();
*tp++ = gtk_assistant_get_type();
*tp++ = gtk_assistant_page_type_get_type();
*tp++ = gtk_attach_options_get_type();
*tp++ = gtk_bin_get_type();
*tp++ = gtk_border_get_type();
*tp++ = gtk_box_get_type();
*tp++ = gtk_buildable_get_type();
*tp++ = gtk_builder_error_get_type();
*tp++ = gtk_builder_get_type();
*tp++ = gtk_button_action_get_type();
*tp++ = gtk_button_box_get_type();
*tp++ = gtk_button_box_style_get_type();
*tp++ = gtk_button_get_type();
*tp++ = gtk_buttons_type_get_type();
*tp++ = gtk_calendar_display_options_get_type();
*tp++ = gtk_calendar_get_type();
*tp++ = gtk_cell_editable_get_type();
*tp++ = gtk_cell_layout_get_type();
*tp++ = gtk_cell_renderer_accel_get_type();
*tp++ = gtk_cell_renderer_accel_mode_get_type();
*tp++ = gtk_cell_renderer_combo_get_type();
*tp++ = gtk_cell_renderer_get_type();
*tp++ = gtk_cell_renderer_mode_get_type();
*tp++ = gtk_cell_renderer_pixbuf_get_type();
*tp++ = gtk_cell_renderer_progress_get_type();
*tp++ = gtk_cell_renderer_spin_get_type();
*tp++ = gtk_cell_renderer_spinner_get_type();
*tp++ = gtk_cell_renderer_state_get_type();
*tp++ = gtk_cell_renderer_text_get_type();
*tp++ = gtk_cell_renderer_toggle_get_type();
*tp++ = gtk_cell_type_get_type();
*tp++ = gtk_cell_view_get_type();
*tp++ = gtk_check_button_get_type();
*tp++ = gtk_check_menu_item_get_type();
*tp++ = gtk_clipboard_get_type();
*tp++ = gtk_clist_drag_pos_get_type();
*tp++ = gtk_color_button_get_type();
*tp++ = gtk_color_selection_dialog_get_type();
*tp++ = gtk_color_selection_get_type();
*tp++ = gtk_combo_box_entry_get_type();
*tp++ = gtk_combo_box_get_type();
*tp++ = gtk_container_get_type();
*tp++ = gtk_corner_type_get_type();
*tp++ = gtk_ctree_expander_style_get_type();
*tp++ = gtk_ctree_expansion_type_get_type();
*tp++ = gtk_ctree_line_style_get_type();
*tp++ = gtk_ctree_pos_get_type();
*tp++ = gtk_curve_type_get_type();
*tp++ = gtk_debug_flag_get_type();
*tp++ = gtk_delete_type_get_type();
*tp++ = gtk_dest_defaults_get_type();
*tp++ = gtk_dialog_flags_get_type();
*tp++ = gtk_dialog_get_type();
*tp++ = gtk_direction_type_get_type();
*tp++ = gtk_drag_result_get_type();
*tp++ = gtk_drawing_area_get_type();
*tp++ = gtk_editable_get_type();
*tp++ = gtk_entry_buffer_get_type();
*tp++ = gtk_entry_completion_get_type();
*tp++ = gtk_entry_get_type();
*tp++ = gtk_entry_icon_position_get_type();
*tp++ = gtk_event_box_get_type();
*tp++ = gtk_expander_get_type();
*tp++ = gtk_expander_style_get_type();
*tp++ = gtk_file_chooser_action_get_type();
*tp++ = gtk_file_chooser_button_get_type();
*tp++ = gtk_file_chooser_confirmation_get_type();
*tp++ = gtk_file_chooser_dialog_get_type();
*tp++ = gtk_file_chooser_error_get_type();
*tp++ = gtk_file_chooser_get_type();
*tp++ = gtk_file_chooser_widget_get_type();
*tp++ = gtk_file_filter_flags_get_type();
*tp++ = gtk_file_filter_get_type();
*tp++ = gtk_fixed_get_type();
*tp++ = gtk_font_button_get_type();
*tp++ = gtk_font_selection_dialog_get_type();
*tp++ = gtk_font_selection_get_type();
*tp++ = gtk_frame_get_type();
*tp++ = gtk_handle_box_get_type();
*tp++ = gtk_hbox_get_type();
*tp++ = gtk_hbutton_box_get_type();
*tp++ = gtk_hpaned_get_type();
*tp++ = gtk_hruler_get_type();
*tp++ = gtk_hscale_get_type();
*tp++ = gtk_hscrollbar_get_type();
*tp++ = gtk_hseparator_get_type();
*tp++ = gtk_hsv_get_type();
*tp++ = gtk_icon_factory_get_type();
*tp++ = gtk_icon_info_get_type();
*tp++ = gtk_icon_lookup_flags_get_type();
*tp++ = gtk_icon_set_get_type();
*tp++ = gtk_icon_size_get_type();
*tp++ = gtk_icon_source_get_type();
*tp++ = gtk_icon_theme_error_get_type();
*tp++ = gtk_icon_theme_get_type();
*tp++ = gtk_icon_view_drop_position_get_type();
*tp++ = gtk_icon_view_get_type();
*tp++ = gtk_identifier_get_type();
*tp++ = gtk_image_get_type();
*tp++ = gtk_image_menu_item_get_type();
*tp++ = gtk_image_type_get_type();
*tp++ = gtk_im_context_get_type();
*tp++ = gtk_im_context_simple_get_type();
*tp++ = gtk_im_multicontext_get_type();
*tp++ = gtk_im_preedit_style_get_type();
*tp++ = gtk_im_status_style_get_type();
*tp++ = gtk_info_bar_get_type();
*tp++ = gtk_invisible_get_type();
*tp++ = gtk_item_get_type();
*tp++ = gtk_justification_get_type();
*tp++ = gtk_label_get_type();
*tp++ = gtk_layout_get_type();
*tp++ = gtk_link_button_get_type();
*tp++ = gtk_list_store_get_type();
*tp++ = gtk_match_type_get_type();
*tp++ = gtk_menu_bar_get_type();
*tp++ = gtk_menu_direction_type_get_type();
*tp++ = gtk_menu_get_type();
*tp++ = gtk_menu_item_get_type();
*tp++ = gtk_menu_shell_get_type();
*tp++ = gtk_menu_tool_button_get_type();
*tp++ = gtk_message_dialog_get_type();
*tp++ = gtk_message_type_get_type();
*tp++ = gtk_metric_type_get_type();
*tp++ = gtk_misc_get_type();
*tp++ = gtk_mount_operation_get_type();
*tp++ = gtk_movement_step_get_type();
*tp++ = gtk_notebook_get_type();
*tp++ = gtk_notebook_tab_get_type();
*tp++ = gtk_number_up_layout_get_type();
*tp++ = gtk_object_flags_get_type();
*tp++ = gtk_object_get_type();
*tp++ = gtk_offscreen_window_get_type();
*tp++ = gtk_orientable_get_type();
*tp++ = gtk_orientation_get_type();
*tp++ = gtk_pack_direction_get_type();
*tp++ = gtk_pack_type_get_type();
*tp++ = gtk_page_orientation_get_type();
*tp++ = gtk_page_set_get_type();
*tp++ = gtk_page_setup_get_type();
*tp++ = gtk_paned_get_type();
*tp++ = gtk_paper_size_get_type();
*tp++ = gtk_path_priority_type_get_type();
*tp++ = gtk_path_type_get_type();
*tp++ = gtk_plug_get_type();
*tp++ = gtk_policy_type_get_type();
*tp++ = gtk_position_type_get_type();
*tp++ = gtk_preview_type_get_type();
*tp++ = gtk_print_context_get_type();
*tp++ = gtk_print_duplex_get_type();
*tp++ = gtk_print_error_get_type();
*tp++ = gtk_print_operation_action_get_type();
*tp++ = gtk_print_operation_get_type();
*tp++ = gtk_print_operation_preview_get_type();
*tp++ = gtk_print_operation_result_get_type();
*tp++ = gtk_print_pages_get_type();
*tp++ = gtk_print_quality_get_type();
*tp++ = gtk_print_settings_get_type();
*tp++ = gtk_print_status_get_type();
*tp++ = gtk_private_flags_get_type();
*tp++ = gtk_progress_bar_get_type();
*tp++ = gtk_progress_bar_orientation_get_type();
*tp++ = gtk_progress_bar_style_get_type();
*tp++ = gtk_radio_action_get_type();
*tp++ = gtk_radio_button_get_type();
*tp++ = gtk_radio_menu_item_get_type();
*tp++ = gtk_radio_tool_button_get_type();
*tp++ = gtk_range_get_type();
*tp++ = gtk_rc_flags_get_type();
*tp++ = gtk_rc_style_get_type();
*tp++ = gtk_rc_token_type_get_type();
*tp++ = gtk_recent_action_get_type();
*tp++ = gtk_recent_chooser_dialog_get_type();
*tp++ = gtk_recent_chooser_error_get_type();
*tp++ = gtk_recent_chooser_get_type();
*tp++ = gtk_recent_chooser_menu_get_type();
*tp++ = gtk_recent_chooser_widget_get_type();
*tp++ = gtk_recent_filter_flags_get_type();
*tp++ = gtk_recent_filter_get_type();
*tp++ = gtk_recent_info_get_type();
*tp++ = gtk_recent_manager_error_get_type();
*tp++ = gtk_recent_manager_get_type();
*tp++ = gtk_recent_sort_type_get_type();
*tp++ = gtk_relief_style_get_type();
*tp++ = gtk_requisition_get_type();
*tp++ = gtk_resize_mode_get_type();
*tp++ = gtk_response_type_get_type();
*tp++ = gtk_ruler_get_type();
*tp++ = gtk_scale_button_get_type();
*tp++ = gtk_scale_get_type();
*tp++ = gtk_scrollbar_get_type();
*tp++ = gtk_scrolled_window_get_type();
*tp++ = gtk_scroll_step_get_type();
*tp++ = gtk_scroll_type_get_type();
*tp++ = gtk_selection_data_get_type();
*tp++ = gtk_selection_mode_get_type();
*tp++ = gtk_sensitivity_type_get_type();
*tp++ = gtk_separator_get_type();
*tp++ = gtk_separator_menu_item_get_type();
*tp++ = gtk_separator_tool_item_get_type();
*tp++ = gtk_settings_get_type();
*tp++ = gtk_shadow_type_get_type();
*tp++ = gtk_side_type_get_type();
*tp++ = gtk_signal_run_type_get_type();
*tp++ = gtk_size_group_get_type();
*tp++ = gtk_size_group_mode_get_type();
*tp++ = gtk_socket_get_type();
*tp++ = gtk_sort_type_get_type();
*tp++ = gtk_spin_button_get_type();
*tp++ = gtk_spin_button_update_policy_get_type();
*tp++ = gtk_spinner_get_type();
*tp++ = gtk_spin_type_get_type();
*tp++ = gtk_state_type_get_type();
*tp++ = gtk_statusbar_get_type();
*tp++ = gtk_status_icon_get_type();
*tp++ = gtk_style_get_type();
*tp++ = gtk_submenu_direction_get_type();
*tp++ = gtk_submenu_placement_get_type();
*tp++ = gtk_table_get_type();
*tp++ = gtk_target_flags_get_type();
*tp++ = gtk_target_list_get_type();
*tp++ = gtk_tearoff_menu_item_get_type();
*tp++ = gtk_text_attributes_get_type();
*tp++ = gtk_text_buffer_get_type();
*tp++ = gtk_text_buffer_target_info_get_type();
*tp++ = gtk_text_child_anchor_get_type();
*tp++ = gtk_text_direction_get_type();
*tp++ = gtk_text_get_type();
*tp++ = gtk_text_iter_get_type();
*tp++ = gtk_text_mark_get_type();
*tp++ = gtk_text_search_flags_get_type();
*tp++ = gtk_text_tag_get_type();
*tp++ = gtk_text_tag_table_get_type();
*tp++ = gtk_text_view_get_type();
*tp++ = gtk_text_window_type_get_type();
*tp++ = gtk_toggle_action_get_type();
*tp++ = gtk_toggle_button_get_type();
*tp++ = gtk_toggle_tool_button_get_type();
*tp++ = gtk_toolbar_child_type_get_type();
*tp++ = gtk_toolbar_get_type();
*tp++ = gtk_toolbar_space_style_get_type();
*tp++ = gtk_toolbar_style_get_type();
*tp++ = gtk_tool_button_get_type();
*tp++ = gtk_tool_item_get_type();
*tp++ = gtk_tool_item_group_get_type();
*tp++ = gtk_tool_palette_drag_targets_get_type();
*tp++ = gtk_tool_palette_get_type();
*tp++ = gtk_tool_shell_get_type();
*tp++ = gtk_tooltip_get_type();
*tp++ = gtk_tree_drag_dest_get_type();
*tp++ = gtk_tree_drag_source_get_type();
*tp++ = gtk_tree_get_type();
*tp++ = gtk_tree_item_get_type();
*tp++ = gtk_tree_iter_get_type();
*tp++ = gtk_tree_model_filter_get_type();
*tp++ = gtk_tree_model_flags_get_type();
*tp++ = gtk_tree_model_get_type();
*tp++ = gtk_tree_model_sort_get_type();
*tp++ = gtk_tree_path_get_type();
*tp++ = gtk_tree_row_reference_get_type();
*tp++ = gtk_tree_selection_get_type();
*tp++ = gtk_tree_sortable_get_type();
*tp++ = gtk_tree_store_get_type();
*tp++ = gtk_tree_view_column_get_type();
*tp++ = gtk_tree_view_column_sizing_get_type();
*tp++ = gtk_tree_view_drop_position_get_type();
*tp++ = gtk_tree_view_get_type();
*tp++ = gtk_tree_view_grid_lines_get_type();
*tp++ = gtk_tree_view_mode_get_type();
*tp++ = gtk_ui_manager_get_type();
*tp++ = gtk_ui_manager_item_type_get_type();
*tp++ = gtk_unit_get_type();
*tp++ = gtk_update_type_get_type();
*tp++ = gtk_vbox_get_type();
*tp++ = gtk_vbutton_box_get_type();
*tp++ = gtk_viewport_get_type();
*tp++ = gtk_visibility_get_type();
*tp++ = gtk_volume_button_get_type();
*tp++ = gtk_vpaned_get_type();
*tp++ = gtk_vruler_get_type();
*tp++ = gtk_vscale_get_type();
*tp++ = gtk_vscrollbar_get_type();
*tp++ = gtk_vseparator_get_type();
*tp++ = gtk_widget_flags_get_type();
*tp++ = gtk_widget_get_type();
*tp++ = gtk_widget_help_type_get_type();
*tp++ = gtk_window_get_type();
*tp++ = gtk_window_group_get_type();
*tp++ = gtk_window_position_get_type();
*tp++ = gtk_window_type_get_type();
*tp++ = gtk_wrap_mode_get_type();
